/*
 * Copyright (c) 2010 Mysema Ltd.
 * All rights reserved.
 *
 */
package com.mysema.converters;

import java.sql.Date;
import java.util.Calendar;

import org.joda.time.LocalDate;
import org.joda.time.format.DateTimeFormat;
import org.joda.time.format.DateTimeFormatter;
import org.joda.time.format.ISODateTimeFormat;

public class DateConverter implements Converter<Date>{

    private final DateTimeFormatter fromStringFmt = ISODateTimeFormat.dateTimeParser().withOffsetParsed();
    
    private final DateTimeFormatter toStringFmt = DateTimeFormat.forPattern("yyyy-MM-ddZ").withOffsetParsed();
    
    @Override
    public Date fromString(String str) {
        LocalDate localDate = fromStringFmt.parseDateTime(str).toLocalDate();
        Calendar cal = Calendar.getInstance();
        cal.setTimeInMillis(0);
        cal.set(Calendar.YEAR, localDate.getYear());
        cal.set(Calendar.MONTH, localDate.getMonthOfYear()-1);
        cal.set(Calendar.DAY_OF_MONTH, localDate.getDayOfMonth());
        return new Date(cal.getTimeInMillis());        
    }

    @Override
    public String toString(Date object) {
        Calendar cal = Calendar.getInstance();
        cal.setTimeInMillis(object.getTime());
        int year = cal.get(Calendar.YEAR);
        int month = cal.get(Calendar.MONTH) + 1;
        int dayOfMonth = cal.get(Calendar.DAY_OF_MONTH);        
        return toStringFmt.print(new LocalDate(year, month, dayOfMonth));
    }

    @Override
    public Class<Date> getJavaType() {
        return Date.class;
    }
    
}
